@@ -110,7 +110,7 @@ origin_edm <- function(events, distance, silent=TRUE){
 #' @references \itemize{
 #'   \item Gatz, D. F., and Smith, L. (1995). The standard error of a weighted mean concentration-I. Bootstrapping vs other methods. Atmospheric Environment, 29(11), 1185-1193. <DOI: 10.1016/1352-2310(94)00210-C>
 #'   \item Gatz, D. F., and Smith, L. (1995). The standard error of a weighted mean concentration-II. Estimating confidence intervals. Atmospheric Environment, 29(11), 1195-1200. <DOI: 10.1016/1352-2310(94)00209-4>
-#'   \item \url{http://r.789695.n4.nabble.com/Problem-with-Weighted-Variance-in-Hmisc-td826437.html}
+#'   \item \url{https://r.789695.n4.nabble.com/Problem-with-Weighted-Variance-in-Hmisc-td826437.html}
 #' }
 #'
 #' @export
@@ -309,6 +309,108 @@ origin_centrality <- function(events, graph, silent=TRUE){
 }
 
 
+TimeMin <- function(num.cases, thres = NA){
+  # Compute the time when a node is infected, for function 'origin_bayesian'
+  ifelse(any(cumsum(num.cases) > thres),
+         min(which(cumsum(num.cases) > thres)), 
+         NA)
+}
+
+
+#origin_bayesian <- function(x) UseMethod("origin_bayesian")
+#' \code{origin_bayesian} Inference Source via Gaussian source estimation with prior information
+#'
+#' @param thres.vec vector, length represents number of cities/nodes, representing thresholds for cities/nodes that they are infected
+#' @param obs.vec list of cities ids used as observers
+#' @param mu.mat matrix- number of cities/nodes x number of observers, each row represents - if this node is the source, the mean of arrival time vector
+#' @param lambda.list a length-number of cities/nodes list, each element is a number of observers x number of observers matrix - if a node is the source, the covariance matrix for arrival time vector
+#' @param poss.candidate.vec a boolean vector indicating if a node has the potential to be the source
+#' @param prior vector, length - number of cities/nodes, prior for cities
+#' @param use.prior boolean, TRUE or FALSE, if use prior, default TRUE
+#'
+#' @return a dataframe with columns 'nodes' and 'probab', indicating nodes indices and their posteriors
+#' 
+#' @examples
+#' # fake training data, indicating format
+#' nnodes <- 851
+#' max.day <- 1312
+#' nsimu <- 20
+#' max.case.per.day <- 10
+#' train.data.fake <- list()
+#' for (j in 1:nnodes) {
+#'   train.data.fake[[j]] <- matrix(sample.int(max.day, 
+#'     size = nsimu*nnodes, replace = TRUE), nrow = nsimu, ncol = nnodes)
+#' }
+#' obs.vec <- (1:9)
+#' candidate.thres <- 0.3
+#' mu.lambda.list <- compute_mu_lambda(train.data.fake, obs.vec, candidate.thres)
+#' # matrix representing number of cases per node per day
+#' cases.node.day <- matrix(sample.int(max.case.per.day, 
+#'   size = nnodes*max.day, replace = TRUE), nrow = nnodes, ncol = max.day)
+#' nnodes <- dim(cases.node.day)[1] # number of nodes
+#' # fixed threshold for all nodes - 10 infected people
+#' thres.vec <- rep(10, nnodes)
+#' # flat/non-informative prior
+#' prior <- rep(1, nnodes) 
+#' result2.df <- origin(events = cases.node.day, type = "bayesian",
+#'                      thres.vec = thres.vec,
+#'                      obs.vec = obs.vec,
+#'                      mu.mat=mu.lambda.list$mu.mat, lambda.list = mu.lambda.list$lambda.list, 
+#'                      poss.candidate.vec=mu.lambda.list$poss.candidate.vec,
+#'                      prior=prior, use.prior=TRUE)
+#' 
+#' @rdname origin
+#' @author Jun Li
+#' @import mvtnorm
+#' @export
+origin_bayesian <- function(events, thres.vec, obs.vec, mu.mat, lambda.list, poss.candidate.vec, prior, use.prior = TRUE){
+  ## constant parameters
+  cases.node.day <- events
+  nnodes <- dim(cases.node.day)[1]
+  
+  ## extract 'observed.time.all'
+  observed.time.all <- rep(NA, 851)
+  for (node.num in 1:851) {
+    if (length(which(cases.node.day[node.num, ] > thres.vec[node.num])) > 0) {
+      observed.time.all[node.num] <- which(cases.node.day[node.num, ] > thres.vec[node.num])[1]
+    } else {
+      observed.time.all[node.num] <- NA
+    }
+  }
+  ## extract info from 'poss.candidate.vec'
+  num.source.candidate = sum(poss.candidate.vec)
+  nodes.canbe.detected <- (1:851)[poss.candidate.vec]
+  ## prepare 'prob.vec'
+  logprob.vec <- rep(NA, num.source.candidate)
+  for (j in 1:num.source.candidate) {
+    if (is.na(lambda.list[[nodes.canbe.detected[j]]][1])) {
+      logprob.vec[j] <- (-Inf)
+    } else {
+      logprob.vec[j] <-
+        dmvnorm(observed.time.all[obs.vec],
+                mean = mu.mat[
+                  nodes.canbe.detected[j], ],
+                sigma = lambda.list[[
+                  nodes.canbe.detected[j]]],
+                log = TRUE)
+    }
+  }
+  if (!use.prior) {
+    prob.vec <- exp(logprob.vec)
+  } else {
+    prob.vec <- exp(logprob.vec) * prior[poss.candidate.vec]
+  }
+  ## prepare final 'df'
+  probnorm.vec <- prob.vec / sum(prob.vec)
+  df <- data.frame(probab = probnorm.vec,
+                   nodes = nodes.canbe.detected)
+  df <- df[rev(order(df$probab)), ]
+  
+  ## return
+  return(df)
+}
+
+
 origin_multiple <- function(events, ...) UseMethod("origin_multiple")
 #' Multiple origin estimation using community partitioning
 #' 
@@ -376,6 +478,4 @@ origin_multiple <- function(events, type=c('edm', 'backtracking', 'centrality'),
         }
     }
     return(res)
-}
-
-
+}
\ No newline at end of file
